summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kinstitutionsview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kinstitutionsview.cpp')
-rw-r--r--kmymoney2/views/kinstitutionsview.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmymoney2/views/kinstitutionsview.cpp b/kmymoney2/views/kinstitutionsview.cpp
index d5a673c..0b9258f 100644
--- a/kmymoney2/views/kinstitutionsview.cpp
+++ b/kmymoney2/views/kinstitutionsview.cpp
@@ -36,8 +36,8 @@
#include "../kmymoneyglobalsettings.h"
#include "../kmymoney2.h"
-KInstitutionsView::KInstitutionsView(TQWidget *tqparent, const char *name) :
- KInstitutionsViewDecl(tqparent,name),
+KInstitutionsView::KInstitutionsView(TQWidget *parent, const char *name) :
+ KInstitutionsViewDecl(parent,name),
m_needReload(false)
{
m_accountTree->header()->setLabel(0, i18n("Institution/Account"));
@@ -129,7 +129,7 @@ void KInstitutionsView::loadAccounts(void)
}
// we need to make sure we show stock accounts
// under the right institution (the one of the tqparent account)
TQMap<TQString, MyMoneyAccount>::iterator it_am;
for(it_am = m_accountMap.begin(); it_am != m_accountMap.end(); ++it_am) {
if((*it_am).isInvest()) {
@@ -199,10 +199,10 @@ void KInstitutionsView::loadAccounts(void)
::timetrace("done load institutions view");
}
-void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* tqparent)
+void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* parent)
{
bool showClosedAccounts = kmymoney2->toggleAction("view_show_all_accounts")->isChecked();
- const MyMoneyAccount& account = dynamic_cast<const MyMoneyAccount&>(tqparent->itemObject());
+ const MyMoneyAccount& account = dynamic_cast<const MyMoneyAccount&>(parent->itemObject());
TQValueList<TQString>::const_iterator it_a;
MyMoneyFile* file = MyMoneyFile::instance();
for(it_a = account.accountList().begin(); it_a != account.accountList().end(); ++it_a) {
@@ -218,13 +218,13 @@ void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* tqparent)
MyMoneySecurity sec = m_securityMap[security.tradingCurrency()];
prices += file->price(sec.id(), file->baseCurrency().id());
}
- KMyMoneyAccountTreeItem* item = new KMyMoneyAccountTreeItem(tqparent, acc, prices, security);
+ KMyMoneyAccountTreeItem* item = new KMyMoneyAccountTreeItem(parent, acc, prices, security);
if(acc.id() == m_reconciliationAccount.id())
item->setReconciliation(true);
}
}
-void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQString& institutionId)
+void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* parent, const TQString& institutionId)
{
MyMoneyFile* file = MyMoneyFile::instance();
@@ -257,7 +257,7 @@ void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const
delete e;
}
- KMyMoneyAccountTreeItem* item = new KMyMoneyAccountTreeItem(tqparent, acc, prices, security);
+ KMyMoneyAccountTreeItem* item = new KMyMoneyAccountTreeItem(parent, acc, prices, security);
if(acc.id() == m_reconciliationAccount.id())
item->setReconciliation(true);
@@ -276,8 +276,8 @@ void KInstitutionsView::loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const
// it does not take the negative sign for liability accounts
// into account. So we correct this here with the value we
// have calculated while filling the list
- tqparent->adjustTotalValue(-tqparent->totalValue()); // load a 0
- tqparent->adjustTotalValue(value); // now store the new value
+ parent->adjustTotalValue(-parent->totalValue()); // load a 0
+ parent->adjustTotalValue(value); // now store the new value
// we need to call slotUpdateNetWorth() here manually, because
// KMyMoneyAccountTreeItem::adjustTotalValue() does not send out
@@ -129,7 +129,7 @@ void KInstitutionsView::loadAccounts(void)
}
// we need to make sure we show stock accounts
- // under the right institution (the one of the tqparent account)
+ // under the right institution (the one of the parent account)
TQMap<TQString, MyMoneyAccount>::iterator it_am;
for(it_am = m_accountMap.begin(); it_am != m_accountMap.end(); ++it_am) {